==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/client/foundation/gui/ModularGuiLineBuilder.java <==
package com.zurrtum.create.client.foundation.gui;

import com.zurrtum.create.catnip.data.Couple;
import com.zurrtum.create.catnip.data.Pair;
import com.zurrtum.create.client.foundation.gui.widget.Label;
import com.zurrtum.create.client.foundation.gui.widget.ScrollInput;
import com.zurrtum.create.client.foundation.gui.widget.SelectionScrollInput;
import com.zurrtum.create.client.foundation.gui.widget.TooltipArea;
import java.util.function.BiConsumer;
import net.minecraft.class_327;
import net.minecraft.class_342;
import net.minecraft.class_5244;

public class ModularGuiLineBuilder {

    private final ModularGuiLine target;
    private final class_327 font;
    private final int x;
    private final int y;

    public ModularGuiLineBuilder(class_327 font, ModularGuiLine target, int x, int y) {
        this.font = font;
        this.target = target;
        this.x = x;
        this.y = y;
    }

    public ModularGuiLineBuilder addScrollInput(int x, int width, BiConsumer<ScrollInput, Label> inputTransform, String dataKey) {
        ScrollInput input = new ScrollInput(x + this.x, y - 4, width, 18);
        addScrollInput(input, inputTransform, dataKey);
        return this;
    }

    public ModularGuiLineBuilder addSelectionScrollInput(int x, int width, BiConsumer<SelectionScrollInput, Label> inputTransform, String dataKey) {
        SelectionScrollInput input = new SelectionScrollInput(x + this.x, y - 4, width, 18);
        addScrollInput(input, inputTransform, dataKey);
        return this;
    }

    public ModularGuiLineBuilder customArea(int x, int width) {
        target.customBoxes.add(Couple.create(x, width));
        return this;
    }

    public ModularGuiLineBuilder speechBubble() {
        target.speechBubble = true;
        return this;
    }

    private <T extends ScrollInput> void addScrollInput(T input, BiConsumer<T, Label> inputTransform, String dataKey) {
        Label label = new Label(input.method_46426() + 5, y, class_5244.field_39003);
        label.withShadow();
        inputTransform.accept(input, label);
        input.writingTo(label);
        target.add(Pair.of(label, "Dummy"));
        target.add(Pair.of(input, dataKey));
    }

    public ModularGuiLineBuilder addIntegerTextInput(int x, int width, BiConsumer<class_342, TooltipArea> inputTransform, String dataKey) {
        return addTextInput(
            x, width, inputTransform.andThen((editBox, $) -> editBox.method_1890(s -> {
                if (s.isEmpty())
                    return true;
                try {
                    Integer.parseInt(s);
                    return true;
                } catch (NumberFormatException e) {
                    return false;
                }
            })), dataKey
        );
    }

    public ModularGuiLineBuilder addTextInput(int x, int width, BiConsumer<class_342, TooltipArea> inputTransform, String dataKey) {
        class_342 input = new class_342(font, x + this.x + 5, y, width - 9, 8, class_5244.field_39003);
        input.method_1858(false);
        input.method_1868(0xffffffff);
        input.method_25365(false);
        input.method_25402(0, 0, 0);
        TooltipArea tooltipArea = new TooltipArea(this.x + x, y - 4, width, 18);
        inputTransform.accept(input, tooltipArea);
        target.add(Pair.of(input, dataKey));
        target.add(Pair.of(tooltipArea, "Dummy"));
        return this;
    }

}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/client/foundation/gui/ModularGuiLineBuilder.java <==
package com.zurrtum.create.client.foundation.gui;

import com.zurrtum.create.catnip.data.Couple;
import com.zurrtum.create.catnip.data.Pair;
import com.zurrtum.create.client.foundation.gui.widget.Label;
import com.zurrtum.create.client.foundation.gui.widget.ScrollInput;
import com.zurrtum.create.client.foundation.gui.widget.SelectionScrollInput;
import com.zurrtum.create.client.foundation.gui.widget.TooltipArea;

import java.util.function.BiConsumer;
import net.minecraft.class_11909;
import net.minecraft.class_11910;
import net.minecraft.class_327;
import net.minecraft.class_342;
import net.minecraft.class_5244;

public class ModularGuiLineBuilder {

    private final ModularGuiLine target;
    private final class_327 font;
    private final int x;
    private final int y;

    public ModularGuiLineBuilder(class_327 font, ModularGuiLine target, int x, int y) {
        this.font = font;
        this.target = target;
        this.x = x;
        this.y = y;
    }

    public ModularGuiLineBuilder addScrollInput(int x, int width, BiConsumer<ScrollInput, Label> inputTransform, String dataKey) {
        ScrollInput input = new ScrollInput(x + this.x, y - 4, width, 18);
        addScrollInput(input, inputTransform, dataKey);
        return this;
    }

    public ModularGuiLineBuilder addSelectionScrollInput(int x, int width, BiConsumer<SelectionScrollInput, Label> inputTransform, String dataKey) {
        SelectionScrollInput input = new SelectionScrollInput(x + this.x, y - 4, width, 18);
        addScrollInput(input, inputTransform, dataKey);
        return this;
    }

    public ModularGuiLineBuilder customArea(int x, int width) {
        target.customBoxes.add(Couple.create(x, width));
        return this;
    }

    public ModularGuiLineBuilder speechBubble() {
        target.speechBubble = true;
        return this;
    }

    private <T extends ScrollInput> void addScrollInput(T input, BiConsumer<T, Label> inputTransform, String dataKey) {
        Label label = new Label(input.method_46426() + 5, y, class_5244.field_39003);
        label.withShadow();
        inputTransform.accept(input, label);
        input.writingTo(label);
        target.add(Pair.of(label, "Dummy"));
        target.add(Pair.of(input, dataKey));
    }

    public ModularGuiLineBuilder addIntegerTextInput(int x, int width, BiConsumer<class_342, TooltipArea> inputTransform, String dataKey) {
        return addTextInput(
            x, width, inputTransform.andThen((editBox, $) -> editBox.method_1890(s -> {
                if (s.isEmpty())
                    return true;
                try {
                    Integer.parseInt(s);
                    return true;
                } catch (NumberFormatException e) {
                    return false;
                }
            })), dataKey
        );
    }

    public ModularGuiLineBuilder addTextInput(int x, int width, BiConsumer<class_342, TooltipArea> inputTransform, String dataKey) {
        class_342 input = new class_342(font, x + this.x + 5, y, width - 9, 8, class_5244.field_39003);
        input.method_1858(false);
        input.method_1868(0xffffffff);
        input.method_25365(false);
        input.method_25402(new class_11909(0, 0, new class_11910(0, 0)), false);
        TooltipArea tooltipArea = new TooltipArea(this.x + x, y - 4, width, 18);
        inputTransform.accept(input, tooltipArea);
        target.add(Pair.of(input, dataKey));
        target.add(Pair.of(tooltipArea, "Dummy"));
        return this;
    }

}
